pub enum RuntimeDocument {
V0(Runtime),
}Expand description
A schema-tagged persisted runtime document.
Variants
V0(Runtime)
The first runtime bundle schema. Older/future schemas are refused rather than guessed at by a runtime process.
Implementations
Sourceimpl RuntimeDocument
impl RuntimeDocument
Sourcepub fn framework_line(&self) -> CompatibilityLine
pub fn framework_line(&self) -> CompatibilityLine
The one compatibility line validated for this execution.
Sourcepub fn participants(&self) -> &[RuntimeParticipant]
pub fn participants(&self) -> &[RuntimeParticipant]
The final participant set, in persisted order.
Sourcepub fn artifacts(&self) -> &BTreeMap<ParticipantArtifactId, BinaryReference>
pub fn artifacts(&self) -> &BTreeMap<ParticipantArtifactId, BinaryReference>
The reusable executable artifacts selected by participant instances.
Sourcepub fn participant(
&self,
id: &ParticipantId,
) -> Result<&RuntimeParticipant, SelectionError>
pub fn participant( &self, id: &ParticipantId, ) -> Result<&RuntimeParticipant, SelectionError>
Find the exact persisted participant selected by a process boundary.