pub struct ParticipantArtifactId(/* private fields */);Expand description
The stable identity of a reusable compiled participant artifact.
The artifact id is the compile-time role identity embedded in the binary.
Multiple ParticipantId instance records may point at the same artifact
when one executable is mounted more than once in a runtime topology.
Implementations
Sourceimpl ParticipantArtifactId
impl ParticipantArtifactId
Sourcepub fn new(
value: impl Into<String>,
) -> Result<ParticipantArtifactId, ParticipantArtifactIdError>
pub fn new( value: impl Into<String>, ) -> Result<ParticipantArtifactId, ParticipantArtifactIdError>
Validate and construct an artifact id.